A Webui task library based on Hop.
==================================

# What is Webui?

Webui allows you to create web applications like you would legos, piecing the framework from reusable components.
See [article](http://www.dartlang.org/articles/web-ui/) for an introduction.

# What is Hop?

Hop is a framework that simplifies and automates console tasks in Dart.  See [Hop Pub package](http://pub.dartlang.org/packages/hop) for more information.  Also see [article](https://github.com/kevmoo/bot.dart/wiki/Using-Hop%2C-Part-1%3A-Building-and-Running-Your-First-Hop-Task-Application) for a quick tutorial.

# How will this library help me?

This library will allow you to:
1. Compile webui components to Javascript in one console step as well as minidart compilation (dart to dart).
2. Fix the relative Urls in the output Webui entry point Html file.
3. Copy static assets such as Javascript linked from the entry point Html file into the target output directory.

_Dart Documentation coming soon._

# How do I get started?

Add the following dependency:

```yaml
dependencies:
  webui_tasks: any
```

# Example

Setup `app.json` to tell tasks how to deploy application.  From [example](https://github.com/damondouglas/webui_tasks.dart/blob/master/example/simple/web/app.json) in [sample webui project](https://github.com/damondouglas/webui_tasks.dart/tree/master/example/simple):
```json
{"link":
    {"style/simple.css":"."},
 "script":
  {
    "packages/browser/dart.js":"lib/dart.js",
    "lib/testme.js":"."
  },
  "app":
  {
    "simple.html_bootstrap.dart":"simple.html_bootstrap.dart.js"
  }
}
```

From [example](https://github.com/damondouglas/webui_tasks.dart/blob/master/example/simple/tool/hop_runner.dart) in [sample webui project](https://github.com/damondouglas/webui_tasks.dart/tree/master/example/simple):
```dart
library hop_runner;

import 'dart:async';
import 'dart:io';
import 'dart:json';
import 'package:hop/hop.dart';
import 'package:hop/hop_tasks.dart';
import 'package:webui_tasks/webui_tasks.dart';

void main() {
  
  String entryPointPath = "web/simple.html";
  
  // Call DWC and dart2js compilers.
  ChainedTask w2d2js = createWebui2JsTask(entryPointPath);
  addTask("w2d2js", w2d2js);
  
  ChainedTask w2d2d = createWebui2MiniDartTask(entryPointPath);
  addTask("w2d2d", w2d2d);
  
  Task deploy = createDeployTask("output/simple.html","web/app.json");
  addTask("deploy", deploy);
  
  runHop();
}
```
### Deploy project as Javascript
1. Run in webui project root as: `dart tool/hop_runner.dart w2d2js` then `dart tool/hop_runner.dart deploy`.
2. Open `output/simple.html` in any modern browser. See [hosted example](https://googledrive.com/host/0B315YrNkj-ZxeEluMlRnX0xOYTQ/simple.html).

### Deploy project as mini dart
1. Change `app.json` so that `app` points to the `_bootstrap.compiled.dart` file.
2. Run in webui project root as `dart tool/hop_runner.dart w2d2d` then `dart tool/hop_runner.dart deploy`.
2. Open `output/simple.html` in Chromium.

## Authors
 * [Damon Douglas](https://github.com/damondouglas) ([+Damon Douglas](https://plus.google.com/u/0/108940381045821372455/))
 * _You? File bugs. Fork and Fix bugs. Let's build this community._

## Acknowledgements
* [Kevin Moore](https://github.com/kevmoo) for his work on the [Hop](https://github.com/kevmoo/hop.dart) and [Webui Widget](https://github.com/kevmoo/widget.dart) libraries, from which much of this code and methodology derives.
* [Seth Ladd](https://github.com/sethladd) for [his original idea](https://groups.google.com/a/dartlang.org/d/msg/web-ui/Xvk3BU8NnxI/S13aR6zh3wYJ) that inspired the project.
